@@ -83,7 +83,7 @@ class AdaLoggingConfig(object):
         try:
             try:
                 log_dir = os.getcwd()
-                logConfig = yaml.load(AdaLoggingConfig.FULL_CONF_YAML_TEST)
+                logConfig = yaml.load(AdaLoggingConfig.FULL_CONF_YAML)
                 logConfig["handlers"]["file"]["filename"] = os.path.join(log_dir, logConfig["handlers"]["file"]["filename"])
 
             except BaseException:
